Module auth

Module auth 

Structs

BearerToken
Adds a bearer credential to every outgoing RPC request.
RpcBearerAuth
Validates bearer credentials on incoming RPC requests.
RpcJwtAuth
Validates HS256 bearer tokens and exposes typed and projected claims to gRPC handlers.
RpcRequestSignatureAuth
Validates gRPC request signatures for one canonical service method target.
RpcRequestSigner
Adds an HMAC request signature to outgoing gRPC metadata.