pub fn load(symbols: &mut SymbolTable)Expand description
Registers the host-prelude defuns into symbols. Must be called AFTER
register_host_fns so the natives the helper bodies reference are present.
pub fn load(symbols: &mut SymbolTable)Registers the host-prelude defuns into symbols. Must be called AFTER
register_host_fns so the natives the helper bodies reference are present.