pub struct RpcMetrics { /* private fields */ }Expand description
Registered gRPC request, latency, and in-flight metrics.
Callers provide the generated RPC method paths up front (for example
/users.Users/Get). Requests for any other path share the unknown label, preventing an
attacker or a misconfigured client from creating an unbounded number of metric series.
Implementations
Sourceimpl RpcMetrics
impl RpcMetrics
pub fn new<I, S>( metrics: &Metrics, namespace: impl Into<String>, mode: RpcMetricMode, methods: I, ) -> Result<Self, MetricsError>