pub struct RpcMetricsBody<B> { /* private fields */ }Trait Implementations
Sourceimpl<B> Body for RpcMetricsBody<B>where
B: Body,
impl<B> Body for RpcMetricsBody<B>where
B: Body,
Sourcefn poll_frame(
self: Pin<&mut Self>,
context: &mut Context<'_>,
) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>>
fn poll_frame( self: Pin<&mut Self>, context: &mut Context<'_>, ) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>>
Attempt to pull out the next frame of this stream. Read more
Sourcefn is_end_stream(&self) -> bool
fn is_end_stream(&self) -> bool
A hint that may return
true when the end of stream has been reached. Read moreSourceimpl<B> Drop for RpcMetricsBody<B>
impl<B> Drop for RpcMetricsBody<B>
impl<'__pin, B> Unpin for RpcMetricsBody<B>where
__Origin<'__pin, B>: Unpin,