Module stack

Module stack 

Generated-service-independent client and server assembly.

Structs

RpcClientStack
RpcClientStackBuilder
Builds one transport service that can be passed directly to any generated Tonic client.
RpcClientStackService
RpcServerStack
RpcServerStackBuilder
Creates the common server layer once and applies it to every generated Tonic service.
RpcServerStackService