HealthReporter

Struct HealthReporter 

pub struct HealthReporter { /* private fields */ }
A handle providing methods to update the health status of gRPC services. A HealthReporter is connected to a HealthServer which serves the statuses over the grpc.health.v1.Health service.

Implementations

Source

impl HealthReporter

pub async fn set_serving<S>(&mut self)
where S: NamedService,

Sets the status of the service implemented by S to Serving. This notifies any watchers if there is a change in status.

Examples found in repository?
examples/echo_server.rs (line 82)
74async fn main() -> Result<(), Box<dyn std::error::Error>> {
75    let address: SocketAddr = "[::1]:50051".parse()?;
76    let server = RpcServer::new(
77        RpcServerConfig::new(address)
78            .with_request_timeout(Duration::from_secs(10))
79            .with_concurrency_limit(1_024),
80    );
81    let (mut reporter, health_service) = health_reporter();
82    reporter.set_serving::<EchoServer<EchoService>>().await;
83
84    server
85        .router()
86        .add_service(health_service)
87        .add_service(EchoServer::new(EchoService))
88        .serve(server.config().address())
89        .await?;
90    Ok(())
91}
pub async fn set_not_serving<S>(&mut self)
where S: NamedService,

Sets the status of the service implemented by S to NotServing. This notifies any watchers if there is a change in status.

pub async fn set_service_status<S>( &mut self, service_name: S, status: ServingStatus, )
where S: AsRef<str>,

Sets the status of the service with service_name to status. This notifies any watchers if there is a change in status.

pub async fn clear_service_status(&mut self, service_name: &str)

Clear the status of the given service.