pub struct RpcTrace { /* private fields */ }Expand description
A W3C trace-context interceptor for Tonic clients and servers.
Implementations
Sourceimpl RpcTrace
impl RpcTrace
Sourcepub fn client(parent: Option<TraceContext>) -> Self
pub fn client(parent: Option<TraceContext>) -> Self
Creates a client interceptor. A configured parent is used to create a child span per call.
Sourcepub fn server() -> Self
pub fn server() -> Self
Creates a server interceptor that accepts traceparent metadata and creates a server span.
Sourcepub fn context<T>(request: &Request<T>) -> Option<TraceContext>
pub fn context<T>(request: &Request<T>) -> Option<TraceContext>
Retrieves the server span installed in a request’s extensions.